@@ -61,7 +61,7 @@ install() {
 		dracut_install /usr/lib*/gcc/**/libgcc_s.so*
 	fi
 	# shellcheck disable=SC2050
-	if [ 0 != 0 ]; then
+	if [ 0 -gt 0 ]; then
 		for d in $libdirs; do
 			[ -e "$d/" ] && dracut_install "$d/"
 		done
@@ -69,8 +69,8 @@ install() {
 	dracut_install /sbin/mount.zfs
 	dracut_install /lib/udev/vdev_id
 	dracut_install awk
-	dracut_install basename
 	dracut_install cut
+	dracut_install tr
 	dracut_install head
 	dracut_install /lib/udev/zvol_id
 	inst_hook cmdline 95 "${moddir}/parse-zfs.sh"
